@@ -865,7 +865,8 @@ def omas_global_quantities(imas_version=omas_rcparams['default_imas_version']):
 
 
 # only attempt cython if user owns this copy of omas
-if os.environ['USER'] != pwd.getpwuid(os.stat(__file__).st_uid).pw_name:
+# disabled for Windows: need to add check for file ownership under Windows
+if os.name == 'nt' or os.environ['USER'] != pwd.getpwuid(os.stat(__file__).st_uid).pw_name:
     with open(os.path.split(__file__)[0] + os.sep + 'omas_cython.pyx', 'r') as f:
         exec(f.read(), globals())
 else:
