@@ -192,6 +192,12 @@ class TestOmasPhysics(UnittestCaseOmas):
         assert ods['summary.global_quantities.beta_tor.value'] is not None
         return
 
+    def test_line_average_density(self):
+        ods = ODS().sample()
+        ods.physics_summary_lineaverage_density()
+        assert ods['summary.line_average.n_e.value'] is not None
+        return
+
     def test_current_from_eq(self):
         ods = ODS().sample_equilibrium()
         ods.physics_current_from_eq(0)
